@@ -2,7 +2,7 @@ package Plack::App::Directory::Markdown;
 use strict;
 use warnings;
 use utf8;
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use parent 'Plack::App::Directory';
 use Encode qw/encode_utf8/;
@@ -10,11 +10,19 @@ use Data::Section::Simple;
 use Text::Xslate;
 use HTTP::Date;
 use URI::Escape qw/uri_escape/;
+use Path::Iterator::Rule;
 use Plack::Middleware::Bootstrap;
 use Plack::Builder;
 
 use Plack::Util::Accessor;
-Plack::Util::Accessor::mk_accessors(__PACKAGE__, qw(title tx tx_path markdown_class markdown_ext callback));
+Plack::Util::Accessor::mk_accessors(__PACKAGE__, qw(
+    title
+    tx
+    tx_path
+    markdown_class
+    markdown_ext
+    callback
+));
 
 sub new {
     my $cls = shift;
@@ -56,6 +64,39 @@ sub markdown {
     $md->markdown(@_);
 }
 
+sub _md_files {
+    my $self = shift;
+    $self->{_md_files} ||= do {
+        my @files;
+        my $rule = Path::Iterator::Rule->new;
+        my $iter = $rule->iter($self->root // '.', {
+            depthfirst => 1,
+        });
+        while ( defined ( my $file = $iter->() ) ) {
+            push @files, $self->remove_root_path($file)
+                if -f -r $file && $self->is_markdown($file);
+        }
+        \@files;
+    };
+}
+
+sub _search_prev_and_next {
+    my ($self, $file) = @_;
+    my ($prev, $next);
+
+    my @md_files = @{ $self->_md_files };
+    my $found;
+    while (defined (my $f = shift @md_files) ) {
+        if ($file eq $f) {
+            $found = 1;
+            $next = shift @md_files;
+            last;
+        }
+        $prev = $f;
+    }
+    $found ? ($prev, $next) : ();
+}
+
 sub serve_path {
     my($self, $env, $dir) = @_;
 
@@ -71,10 +112,13 @@ sub serve_path {
             my $path = $self->remove_root_path($dir);
             $path =~ s/\.(?:markdown|mk?dn?)$//;
 
+            my ($prev, $next) = $self->_search_prev_and_next($self->remove_root_path($dir));
             my $page = $self->tx->render('md.tx', {
                 path    => $path,
                 title   => ($self->title || 'Markdown'),
                 content => $content,
+                prev    => $prev,
+                next    => $next,
             });
             $page = encode_utf8($page);
 
@@ -187,6 +231,11 @@ __DATA__
 <title><: $title :></title>
 <style type="text/css">
   img { max-width: 100%; }
+  ul.paginate { padding: 0; }
+  ul.paginate li { display: inline; }
+  ul.paginate li.prev::before { content: "\00ab  "; // laquo; }
+  ul.paginate li.next::after { content: "  \00bb"; // raquo; }
+  ul.paginate li + li::before { content: ' | '; }
 </style>
 <!-- you can locate your style.css and adjust styles -->
 <link rel="stylesheet" type="text/css" media="all" href="/style.css" />
@@ -239,9 +288,22 @@ __DATA__
 / <a href="<: $part.link :>"><: $part.name :></a>
 : }
 </h1>
+: include paginate
 : $content | mark_raw
+: include paginate
 : } # endblock body
 
+@@ paginate.tx
+<nav>
+  <ul class="paginate">
+: if $prev {
+    <li class="prev"><a href="/<: $prev :>"><: $prev :></a></li>
+: }
+: if $next {
+    <li class="next"><a href="/<: $next :>"><: $next :></a></li>
+: }
+  </ul>
+
 __END__
 
 =head1 NAME
